@@ -32,7 +32,7 @@ def _run(aux: tuple, data: dict, left: int,
          start_est=True, compute_pdf=False, k_left_bound=1,
          adjusted_loglik=False, adjust_line=False, regul_alpha=0.0, 
          regul_n=True, regul_slice=True, regul_prior='laplace', std=False, 
-         fix_params=str(), use_cpu=False):
+         fix_params=str(),optimizer='SLSQP', use_cpu=False):
     if use_cpu:
         os.environ["JAX_PLATFORM_NAME"] = 'cpu'
         os.environ["XLA_PYTHON_CLIENT_ALLOCATOR"] = 'cpu'
@@ -51,7 +51,7 @@ def _run(aux: tuple, data: dict, left: int,
                    'regul_n': regul_n, 'regul_slice': regul_slice,
                    'regul_prior': regul_prior, 'fix_params': fix_params}
     model = get_model_creator(**inst_params)()
-    fit = model.fit(data, calc_std=std)
+    fit = model.fit(data, calc_std=std, optimizer=optimizer)
     _finalize_fit(model, fit)
     stds = list()
     ests = list()
@@ -90,7 +90,7 @@ def fit(name: str, model='line', dist='BetaNB', left=None,
         window_behavior='both', min_slices=1, adjust_line=False, k_left_bound=1,
         max_count=np.inf, max_cover=np.inf, apply_weights=False,  start_est=True,
         adjusted_loglik=False, regul_alpha=0.0, regul_n=True, regul_slice=True, 
-        regul_prior='laplace', std=False, fix_params=str(), n_jobs=1):
+        regul_prior='laplace', std=False, fix_params=str(), optimizer='SLSQP', n_jobs=1):
     """
 
     Parameters
@@ -177,6 +177,7 @@ def fit(name: str, model='line', dist='BetaNB', left=None,
                   regul_prior=regul_prior,
                   std=std,
                   fix_params=fix_params,
+                  optimizer=optimizer,
                   use_cpu=(n_jobs != 1))
     result = defaultdict(lambda: defaultdict())
     ralt = {True: 'alt', False: 'ref'}
